# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MobileTokenResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"expires": "str", "mobile_token": "str"}

    attribute_map = {"expires": "expires", "mobile_token": "mobile_token"}

    def __init__(self, expires=None, mobile_token=None):  # noqa: E501
        """MobileTokenResponse - a model defined in Swagger"""  # noqa: E501

        self._expires = None
        self._mobile_token = None
        self.discriminator = None

        if expires is not None:
            self.expires = expires
        if mobile_token is not None:
            self.mobile_token = mobile_token

    @property
    def expires(self):
        """Gets the expires of this MobileTokenResponse.  # noqa: E501

        Date and time of mobile token expiration in ISO 8601 format, example of format - yyyy-MM-dd'T'HH:mm:ss.SSS'Z'  # noqa: E501

        :return: The expires of this MobileTokenResponse.  # noqa: E501
        :rtype: str
        """
        return self._expires

    @expires.setter
    def expires(self, expires):
        """Sets the expires of this MobileTokenResponse.

        Date and time of mobile token expiration in ISO 8601 format, example of format - yyyy-MM-dd'T'HH:mm:ss.SSS'Z'  # noqa: E501

        :param expires: The expires of this MobileTokenResponse.  # noqa: E501
        :type: str
        """

        self._expires = expires

    @property
    def mobile_token(self):
        """Gets the mobile_token of this MobileTokenResponse.  # noqa: E501

        Unique identifier, max 128 symbols  # noqa: E501

        :return: The mobile_token of this MobileTokenResponse.  # noqa: E501
        :rtype: str
        """
        return self._mobile_token

    @mobile_token.setter
    def mobile_token(self, mobile_token):
        """Sets the mobile_token of this MobileTokenResponse.

        Unique identifier, max 128 symbols  # noqa: E501

        :param mobile_token: The mobile_token of this MobileTokenResponse.  # noqa: E501
        :type: str
        """

        self._mobile_token = mobile_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(MobileTokenResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MobileTokenResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.payment_response_card_account import (
    PaymentResponseCardAccount,
)  # noqa: F401,E501
from cardpay.model.recurring_customer import RecurringCustomer  # noqa: F401,E501
from cardpay.model.recurring_response_merchant_order import (
    RecurringResponseMerchantOrder,
)  # noqa: F401,E501
from cardpay.model.recurring_response_recurring_data import (
    RecurringResponseRecurringData,
)  # noqa: F401,E501


class RecurringResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "payment_method": "str",
        "merchant_order": "RecurringResponseMerchantOrder",
        "recurring_data": "RecurringResponseRecurringData",
        "card_account": "PaymentResponseCardAccount",
        "customer": "RecurringCustomer",
    }

    attribute_map = {
        "payment_method": "payment_method",
        "merchant_order": "merchant_order",
        "recurring_data": "recurring_data",
        "card_account": "card_account",
        "customer": "customer",
    }

    def __init__(
        self,
        payment_method=None,
        merchant_order=None,
        recurring_data=None,
        card_account=None,
        customer=None,
    ):  # noqa: E501
        """RecurringResponse - a model defined in Swagger"""  # noqa: E501

        self._payment_method = None
        self._merchant_order = None
        self._recurring_data = None
        self._card_account = None
        self._customer = None
        self.discriminator = None

        if payment_method is not None:
            self.payment_method = payment_method
        if merchant_order is not None:
            self.merchant_order = merchant_order
        if recurring_data is not None:
            self.recurring_data = recurring_data
        if card_account is not None:
            self.card_account = card_account
        if customer is not None:
            self.customer = customer

    @property
    def payment_method(self):
        """Gets the payment_method of this RecurringResponse.  # noqa: E501

        Used payment method type name from payment methods list  # noqa: E501

        :return: The payment_method of this RecurringResponse.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this RecurringResponse.

        Used payment method type name from payment methods list  # noqa: E501

        :param payment_method: The payment_method of this RecurringResponse.  # noqa: E501
        :type: str
        """

        self._payment_method = payment_method

    @property
    def merchant_order(self):
        """Gets the merchant_order of this RecurringResponse.  # noqa: E501

        Merchant order data  # noqa: E501

        :return: The merchant_order of this RecurringResponse.  # noqa: E501
        :rtype: RecurringResponseMerchantOrder
        """
        return self._merchant_order

    @merchant_order.setter
    def merchant_order(self, merchant_order):
        """Sets the merchant_order of this RecurringResponse.

        Merchant order data  # noqa: E501

        :param merchant_order: The merchant_order of this RecurringResponse.  # noqa: E501
        :type: RecurringResponseMerchantOrder
        """

        self._merchant_order = merchant_order

    @property
    def recurring_data(self):
        """Gets the recurring_data of this RecurringResponse.  # noqa: E501

        Recurring data  # noqa: E501

        :return: The recurring_data of this RecurringResponse.  # noqa: E501
        :rtype: RecurringResponseRecurringData
        """
        return self._recurring_data

    @recurring_data.setter
    def recurring_data(self, recurring_data):
        """Sets the recurring_data of this RecurringResponse.

        Recurring data  # noqa: E501

        :param recurring_data: The recurring_data of this RecurringResponse.  # noqa: E501
        :type: RecurringResponseRecurringData
        """

        self._recurring_data = recurring_data

    @property
    def card_account(self):
        """Gets the card_account of this RecurringResponse.  # noqa: E501

        Card account data  # noqa: E501

        :return: The card_account of this RecurringResponse.  # noqa: E501
        :rtype: PaymentResponseCardAccount
        """
        return self._card_account

    @card_account.setter
    def card_account(self, card_account):
        """Sets the card_account of this RecurringResponse.

        Card account data  # noqa: E501

        :param card_account: The card_account of this RecurringResponse.  # noqa: E501
        :type: PaymentResponseCardAccount
        """

        self._card_account = card_account

    @property
    def customer(self):
        """Gets the customer of this RecurringResponse.  # noqa: E501

        Customer data  # noqa: E501

        :return: The customer of this RecurringResponse.  # noqa: E501
        :rtype: RecurringCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this RecurringResponse.

        Customer data  # noqa: E501

        :param customer: The customer of this RecurringResponse.  # noqa: E501
        :type: RecurringCustomer
        """

        self._customer = customer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(RecurringResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecurringResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cardpay.api_client import ApiClient


class RecurringsInstallmentsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def calculate_schedule(self, currency, request_id, **kwargs):  # noqa: E501
        """Get calculation of installment payment options  # noqa: E501

        :param str currency: [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code (required)
        :param str request_id: Request ID (required)
        :param float total_amount: Total amount of subscription to be calculated to options; can have dot as a decimal separator.
        :return: ScheduleOptionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.calculate_schedule_with_http_info(
            currency, request_id, **kwargs
        )  # noqa: E501
        return data

    def calculate_schedule_with_http_info(
        self, currency, request_id, **kwargs
    ):  # noqa: E501
        """Get calculation of installment payment options  # noqa: E501

        :param str currency: [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code (required)
        :param str request_id: Request ID (required)
        :param float total_amount: Total amount of subscription to be calculated to options; can have dot as a decimal separator.
        :return: ScheduleOptionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["currency", "request_id", "total_amount"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method calculate_schedule" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'currency' is set
        if "currency" not in params or params["currency"] is None:
            raise ValueError(
                "Missing the required parameter `currency` when calling `calculate_schedule`"
            )  # noqa: E501
        # verify the required parameter 'request_id' is set
        if "request_id" not in params or params["request_id"] is None:
            raise ValueError(
                "Missing the required parameter `request_id` when calling `calculate_schedule`"
            )  # noqa: E501

        if "request_id" in params and len(params["request_id"]) > 50:
            raise ValueError(
                "Invalid value for parameter `request_id` when calling `calculate_schedule`, length must be less than or equal to `50`"
            )  # noqa: E501
        if "request_id" in params and len(params["request_id"]) < 0:
            raise ValueError(
                "Invalid value for parameter `request_id` when calling `calculate_schedule`, length must be greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if "currency" in params:
            query_params.append(("currency", params["currency"]))  # noqa: E501
        if "request_id" in params:
            query_params.append(("request_id", params["request_id"]))  # noqa: E501
        if "total_amount" in params:
            query_params.append(("totalAmount", params["total_amount"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/installments/options_calculator",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ScheduleOptionsResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def create_installment(self, subscription_request, **kwargs):  # noqa: E501
        """Create installment  # noqa: E501

        :param InstallmentSubscriptionRequest subscription_request: subscriptionRequest (required)
        :return: RecurringGatewayCreationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.create_installment_with_http_info(
            subscription_request, **kwargs
        )  # noqa: E501
        return data

    def create_installment_with_http_info(
        self, subscription_request, **kwargs
    ):  # noqa: E501
        """Create installment  # noqa: E501

        :param InstallmentSubscriptionRequest subscription_request: subscriptionRequest (required)
        :return: RecurringGatewayCreationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["subscription_request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_installment" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'subscription_request' is set
        if (
            "subscription_request" not in params
            or params["subscription_request"] is None
        ):
            raise ValueError(
                "Missing the required parameter `subscription_request` when calling `create_installment`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "subscription_request" in params:
            body_params = params["subscription_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/installments",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RecurringGatewayCreationResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_installment_payment(self, recurring_id, **kwargs):  # noqa: E501
        """Get installment payment  # noqa: E501

        :param str recurring_id: Recurring ID (required)
        :return: RecurringResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.get_installment_payment_with_http_info(
            recurring_id, **kwargs
        )  # noqa: E501
        return data

    def get_installment_payment_with_http_info(
        self, recurring_id, **kwargs
    ):  # noqa: E501
        """Get installment payment  # noqa: E501

        :param str recurring_id: Recurring ID (required)
        :return: RecurringResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["recurring_id"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_installment_payment" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'recurring_id' is set
        if "recurring_id" not in params or params["recurring_id"] is None:
            raise ValueError(
                "Missing the required parameter `recurring_id` when calling `get_installment_payment`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "recurring_id" in params:
            path_params["recurringId"] = params["recurring_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/installments/{recurringId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RecurringResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_installment_payments(self, request_id, **kwargs):  # noqa: E501
        """Get installment payments  # noqa: E501

        :param str request_id: Request ID (required)
        :param str currency: [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of transactions currency
        :param datetime end_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period ends (not inclusive), UTC time, must be less than 7 days after 'start_time', default is current time (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param int max_count: Limit number of returned transactions (must be less than 10000, default is 1000)
        :param str merchant_order_id: Merchant order number from the merchant system
        :param str payment_method: Used payment method type name from payment methods list
        :param list[str] recurring_types:
        :param str sort_order: Sort based on order of results. `asc` for ascending order or `desc` for descending order (default value)
        :param datetime start_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period starts (inclusive), UTC time, default is 24 hours before 'end_time' (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param str type: Filter recurring payments by certain type (applicable to /api/recurrings endpoint only): `SCHEDULED` for scheduled recurring payments `ONECLICK` for one-click payments `INSTALLMENT` for installment payments
        :return: RecurringsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.get_installment_payments_with_http_info(
            request_id, **kwargs
        )  # noqa: E501
        return data

    def get_installment_payments_with_http_info(
        self, request_id, **kwargs
    ):  # noqa: E501
        """Get installment payments  # noqa: E501

        :param str request_id: Request ID (required)
        :param str currency: [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of transactions currency
        :param datetime end_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period ends (not inclusive), UTC time, must be less than 7 days after 'start_time', default is current time (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param int max_count: Limit number of returned transactions (must be less than 10000, default is 1000)
        :param str merchant_order_id: Merchant order number from the merchant system
        :param str payment_method: Used payment method type name from payment methods list
        :param list[str] recurring_types:
        :param str sort_order: Sort based on order of results. `asc` for ascending order or `desc` for descending order (default value)
        :param datetime start_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period starts (inclusive), UTC time, default is 24 hours before 'end_time' (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param str type: Filter recurring payments by certain type (applicable to /api/recurrings endpoint only): `SCHEDULED` for scheduled recurring payments `ONECLICK` for one-click payments `INSTALLMENT` for installment payments
        :return: RecurringsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "request_id",
            "currency",
            "end_time",
            "max_count",
            "merchant_order_id",
            "payment_method",
            "recurring_types",
            "sort_order",
            "start_time",
            "type",
        ]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_installment_payments" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request_id' is set
        if "request_id" not in params or params["request_id"] is None:
            raise ValueError(
                "Missing the required parameter `request_id` when calling `get_installment_payments`"
            )  # noqa: E501

        if "request_id" in params and len(params["request_id"]) > 50:
            raise ValueError(
                "Invalid value for parameter `request_id` when calling `get_installment_payments`, length must be less than or equal to `50`"
            )  # noqa: E501
        if "request_id" in params and len(params["request_id"]) < 0:
            raise ValueError(
                "Invalid value for parameter `request_id` when calling `get_installment_payments`, length must be greater than or equal to `0`"
            )  # noqa: E501
        if "max_count" in params and params["max_count"] > 10000:  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `max_count` when calling `get_installment_payments`, must be a value less than or equal to `10000`"
            )  # noqa: E501
        if "merchant_order_id" in params and len(params["merchant_order_id"]) > 50:
            raise ValueError(
                "Invalid value for parameter `merchant_order_id` when calling `get_installment_payments`, length must be less than or equal to `50`"
            )  # noqa: E501
        if "merchant_order_id" in params and len(params["merchant_order_id"]) < 0:
            raise ValueError(
                "Invalid value for parameter `merchant_order_id` when calling `get_installment_payments`, length must be greater than or equal to `0`"
            )  # noqa: E501
        if "payment_method" in params and len(params["payment_method"]) > 100:
            raise ValueError(
                "Invalid value for parameter `payment_method` when calling `get_installment_payments`, length must be less than or equal to `100`"
            )  # noqa: E501
        if "payment_method" in params and len(params["payment_method"]) < 0:
            raise ValueError(
                "Invalid value for parameter `payment_method` when calling `get_installment_payments`, length must be greater than or equal to `0`"
            )  # noqa: E501
        if "sort_order" in params and not re.search(
            r"asc|desc", params["sort_order"]
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `sort_order` when calling `get_installment_payments`, must conform to the pattern `/asc|desc/`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if "currency" in params:
            query_params.append(("currency", params["currency"]))  # noqa: E501
        if "end_time" in params:
            query_params.append(("end_time", params["end_time"]))  # noqa: E501
        if "max_count" in params:
            query_params.append(("max_count", params["max_count"]))  # noqa: E501
        if "merchant_order_id" in params:
            query_params.append(
                ("merchant_order_id", params["merchant_order_id"])
            )  # noqa: E501
        if "payment_method" in params:
            query_params.append(
                ("payment_method", params["payment_method"])
            )  # noqa: E501
        if "recurring_types" in params:
            query_params.append(
                ("recurring_types", params["recurring_types"])
            )  # noqa: E501
            collection_formats["recurring_types"] = "multi"  # noqa: E501
        if "request_id" in params:
            query_params.append(("request_id", params["request_id"]))  # noqa: E501
        if "sort_order" in params:
            query_params.append(("sort_order", params["sort_order"]))  # noqa: E501
        if "start_time" in params:
            query_params.append(("start_time", params["start_time"]))  # noqa: E501
        if "type" in params:
            query_params.append(("type", params["type"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/installments",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RecurringsList",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def update_installment_payment(
        self, recurring_id, recurring_patch_request, **kwargs
    ):  # noqa: E501
        """Update installment payment  # noqa: E501

        :param str recurring_id: Recurring ID (required)
        :param RecurringPatchRequest recurring_patch_request: Recurring patch request (required)
        :return: RecurringResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.update_installment_payment_with_http_info(
            recurring_id, recurring_patch_request, **kwargs
        )  # noqa: E501
        return data

    def update_installment_payment_with_http_info(
        self, recurring_id, recurring_patch_request, **kwargs
    ):  # noqa: E501
        """Update installment payment  # noqa: E501

        :param str recurring_id: Recurring ID (required)
        :param RecurringPatchRequest recurring_patch_request: Recurring patch request (required)
        :return: RecurringResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["recurring_id", "recurring_patch_request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_installment_payment" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'recurring_id' is set
        if "recurring_id" not in params or params["recurring_id"] is None:
            raise ValueError(
                "Missing the required parameter `recurring_id` when calling `update_installment_payment`"
            )  # noqa: E501
        # verify the required parameter 'recurring_patch_request' is set
        if (
            "recurring_patch_request" not in params
            or params["recurring_patch_request"] is None
        ):
            raise ValueError(
                "Missing the required parameter `recurring_patch_request` when calling `update_installment_payment`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "recurring_id" in params:
            path_params["recurringId"] = params["recurring_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "recurring_patch_request" in params:
            body_params = params["recurring_patch_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/installments/{recurringId}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RecurringResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cardpay.api_client import ApiClient


class MobileApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_mobile_payment(self, request, **kwargs):  # noqa: E501
        """Create mobile payment   # noqa: E501

        :param MobilePaymentRequest request: request (required)
        :return: MobilePaymentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.create_mobile_payment_with_http_info(
            request, **kwargs
        )  # noqa: E501
        return data

    def create_mobile_payment_with_http_info(self, request, **kwargs):  # noqa: E501
        """Create mobile payment   # noqa: E501

        :param MobilePaymentRequest request: request (required)
        :return: MobilePaymentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_mobile_payment" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request' is set
        if "request" not in params or params["request"] is None:
            raise ValueError(
                "Missing the required parameter `request` when calling `create_mobile_payment`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "request" in params:
            body_params = params["request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/mobile/payment",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="MobilePaymentResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def execute_card_binding(self, request, **kwargs):  # noqa: E501
        """Execute card binding process  # noqa: E501

        :param CardBindingRequest request: request (required)
        :return: CardBindingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.execute_card_binding_with_http_info(
            request, **kwargs
        )  # noqa: E501
        return data

    def execute_card_binding_with_http_info(self, request, **kwargs):  # noqa: E501
        """Execute card binding process  # noqa: E501

        :param CardBindingRequest request: request (required)
        :return: CardBindingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method execute_card_binding" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request' is set
        if "request" not in params or params["request"] is None:
            raise ValueError(
                "Missing the required parameter `request` when calling `execute_card_binding`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "request" in params:
            body_params = params["request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/mobile/cardbinding",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CardBindingResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def generate_mobile_token(self, request, **kwargs):  # noqa: E501
        """Generate mobile token   # noqa: E501

        :param MobileTokenRequest request: request (required)
        :return: MobileTokenResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.generate_mobile_token_with_http_info(
            request, **kwargs
        )  # noqa: E501
        return data

    def generate_mobile_token_with_http_info(self, request, **kwargs):  # noqa: E501
        """Generate mobile token   # noqa: E501

        :param MobileTokenRequest request: request (required)
        :return: MobileTokenResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_mobile_token" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request' is set
        if "request" not in params or params["request"] is None:
            raise ValueError(
                "Missing the required parameter `request` when calling `generate_mobile_token`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "request" in params:
            body_params = params["request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/mobile/token",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="MobileTokenResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.refund_request_customer import (
    RefundRequestCustomer,
)  # noqa: F401,E501
from cardpay.model.refund_request_e_wallet_account import (
    RefundRequestEWalletAccount,
)  # noqa: F401,E501
from cardpay.model.refund_request_merchant_order import (
    RefundRequestMerchantOrder,
)  # noqa: F401,E501
from cardpay.model.refund_request_payment_data import (
    RefundRequestPaymentData,
)  # noqa: F401,E501
from cardpay.model.refund_request_refund_data import (
    RefundRequestRefundData,
)  # noqa: F401,E501
from cardpay.model.request import Request  # noqa: F401,E501


class RefundRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "request": "Request",
        "customer": "RefundRequestCustomer",
        "ewallet_account": "RefundRequestEWalletAccount",
        "merchant_order": "RefundRequestMerchantOrder",
        "payment_data": "RefundRequestPaymentData",
        "refund_data": "RefundRequestRefundData",
    }

    attribute_map = {
        "request": "request",
        "customer": "customer",
        "ewallet_account": "ewallet_account",
        "merchant_order": "merchant_order",
        "payment_data": "payment_data",
        "refund_data": "refund_data",
    }

    def __init__(
        self,
        request=None,
        customer=None,
        ewallet_account=None,
        merchant_order=None,
        payment_data=None,
        refund_data=None,
    ):  # noqa: E501
        """RefundRequest - a model defined in Swagger"""  # noqa: E501

        self._request = None
        self._customer = None
        self._ewallet_account = None
        self._merchant_order = None
        self._payment_data = None
        self._refund_data = None
        self.discriminator = None

        self.request = request
        if customer is not None:
            self.customer = customer
        if ewallet_account is not None:
            self.ewallet_account = ewallet_account
        if merchant_order is not None:
            self.merchant_order = merchant_order
        self.payment_data = payment_data
        if refund_data is not None:
            self.refund_data = refund_data

    @property
    def request(self):
        """Gets the request of this RefundRequest.  # noqa: E501

        Request  # noqa: E501

        :return: The request of this RefundRequest.  # noqa: E501
        :rtype: Request
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this RefundRequest.

        Request  # noqa: E501

        :param request: The request of this RefundRequest.  # noqa: E501
        :type: Request
        """
        if request is None:
            raise ValueError(
                "Invalid value for `request`, must not be `None`"
            )  # noqa: E501

        self._request = request

    @property
    def customer(self):
        """Gets the customer of this RefundRequest.  # noqa: E501

        Customer  # noqa: E501

        :return: The customer of this RefundRequest.  # noqa: E501
        :rtype: RefundRequestCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this RefundRequest.

        Customer  # noqa: E501

        :param customer: The customer of this RefundRequest.  # noqa: E501
        :type: RefundRequestCustomer
        """

        self._customer = customer

    @property
    def ewallet_account(self):
        """Gets the ewallet_account of this RefundRequest.  # noqa: E501

        EWallet  # noqa: E501

        :return: The ewallet_account of this RefundRequest.  # noqa: E501
        :rtype: RefundRequestEWalletAccount
        """
        return self._ewallet_account

    @ewallet_account.setter
    def ewallet_account(self, ewallet_account):
        """Sets the ewallet_account of this RefundRequest.

        EWallet  # noqa: E501

        :param ewallet_account: The ewallet_account of this RefundRequest.  # noqa: E501
        :type: RefundRequestEWalletAccount
        """

        self._ewallet_account = ewallet_account

    @property
    def merchant_order(self):
        """Gets the merchant_order of this RefundRequest.  # noqa: E501

        Merchant order data  # noqa: E501

        :return: The merchant_order of this RefundRequest.  # noqa: E501
        :rtype: RefundRequestMerchantOrder
        """
        return self._merchant_order

    @merchant_order.setter
    def merchant_order(self, merchant_order):
        """Sets the merchant_order of this RefundRequest.

        Merchant order data  # noqa: E501

        :param merchant_order: The merchant_order of this RefundRequest.  # noqa: E501
        :type: RefundRequestMerchantOrder
        """

        self._merchant_order = merchant_order

    @property
    def payment_data(self):
        """Gets the payment_data of this RefundRequest.  # noqa: E501

        Payment data  # noqa: E501

        :return: The payment_data of this RefundRequest.  # noqa: E501
        :rtype: RefundRequestPaymentData
        """
        return self._payment_data

    @payment_data.setter
    def payment_data(self, payment_data):
        """Sets the payment_data of this RefundRequest.

        Payment data  # noqa: E501

        :param payment_data: The payment_data of this RefundRequest.  # noqa: E501
        :type: RefundRequestPaymentData
        """
        if payment_data is None:
            raise ValueError(
                "Invalid value for `payment_data`, must not be `None`"
            )  # noqa: E501

        self._payment_data = payment_data

    @property
    def refund_data(self):
        """Gets the refund_data of this RefundRequest.  # noqa: E501

        Refund data  # noqa: E501

        :return: The refund_data of this RefundRequest.  # noqa: E501
        :rtype: RefundRequestRefundData
        """
        return self._refund_data

    @refund_data.setter
    def refund_data(self, refund_data):
        """Sets the refund_data of this RefundRequest.

        Refund data  # noqa: E501

        :param refund_data: The refund_data of this RefundRequest.  # noqa: E501
        :type: RefundRequestRefundData
        """

        self._refund_data = refund_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(RefundRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RefundRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SubscriptionFilterParameters(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "request_id": "str",
        "max_count": "int",
        "offset": "int",
        "sort_order": "str",
        "customer_id": "str",
        "plan_id": "str",
        "start_time": "datetime",
        "end_time": "datetime",
        "currency": "str",
        "status": "str",
        "type": "str",
    }

    attribute_map = {
        "request_id": "request_id",
        "max_count": "max_count",
        "offset": "offset",
        "sort_order": "sort_order",
        "customer_id": "customer_id",
        "plan_id": "plan_id",
        "start_time": "start_time",
        "end_time": "end_time",
        "currency": "currency",
        "status": "status",
        "type": "type",
    }

    def __init__(
        self,
        request_id=None,
        max_count=None,
        offset=None,
        sort_order=None,
        customer_id=None,
        plan_id=None,
        start_time=None,
        end_time=None,
        currency=None,
        status=None,
        type=None,
    ):  # noqa: E501
        """SubscriptionFilterParameters - a model defined in Swagger"""  # noqa: E501

        self._request_id = None
        self._max_count = None
        self._offset = None
        self._sort_order = None
        self._customer_id = None
        self._plan_id = None
        self._start_time = None
        self._end_time = None
        self._currency = None
        self._status = None
        self._type = None
        self.discriminator = None

        self.request_id = request_id
        if max_count is not None:
            self.max_count = max_count
        if offset is not None:
            self.offset = offset
        if sort_order is not None:
            self.sort_order = sort_order
        if customer_id is not None:
            self.customer_id = customer_id
        if plan_id is not None:
            self.plan_id = plan_id
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if currency is not None:
            self.currency = currency
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type

    @property
    def request_id(self):
        """Gets the request_id of this SubscriptionFilterParameters.  # noqa: E501

        Request ID  # noqa: E501

        :return: The request_id of this SubscriptionFilterParameters.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this SubscriptionFilterParameters.

        Request ID  # noqa: E501

        :param request_id: The request_id of this SubscriptionFilterParameters.  # noqa: E501
        :type: str
        """
        if request_id is None:
            raise ValueError(
                "Invalid value for `request_id`, must not be `None`"
            )  # noqa: E501
        if request_id is not None and len(request_id) > 50:
            raise ValueError(
                "Invalid value for `request_id`, length must be less than or equal to `50`"
            )  # noqa: E501
        if request_id is not None and len(request_id) < 1:
            raise ValueError(
                "Invalid value for `request_id`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._request_id = request_id

    @property
    def max_count(self):
        """Gets the max_count of this SubscriptionFilterParameters.  # noqa: E501

        Limit number of returned subscriptions (must be less than 10000, default is 1000)  # noqa: E501

        :return: The max_count of this SubscriptionFilterParameters.  # noqa: E501
        :rtype: int
        """
        return self._max_count

    @max_count.setter
    def max_count(self, max_count):
        """Sets the max_count of this SubscriptionFilterParameters.

        Limit number of returned subscriptions (must be less than 10000, default is 1000)  # noqa: E501

        :param max_count: The max_count of this SubscriptionFilterParameters.  # noqa: E501
        :type: int
        """
        if max_count is not None and max_count > 10000:  # noqa: E501
            raise ValueError(
                "Invalid value for `max_count`, must be a value less than or equal to `10000`"
            )  # noqa: E501
        if max_count is not None and max_count < 1:  # noqa: E501
            raise ValueError(
                "Invalid value for `max_count`, must be a value greater than or equal to `1`"
            )  # noqa: E501

        self._max_count = max_count

    @property
    def offset(self):
        """Gets the offset of this SubscriptionFilterParameters.  # noqa: E501

        Offset (must be less than 10000)  # noqa: E501

        :return: The offset of this SubscriptionFilterParameters.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this SubscriptionFilterParameters.

        Offset (must be less than 10000)  # noqa: E501

        :param offset: The offset of this SubscriptionFilterParameters.  # noqa: E501
        :type: int
        """
        if offset is not None and offset > 10000:  # noqa: E501
            raise ValueError(
                "Invalid value for `offset`, must be a value less than or equal to `10000`"
            )  # noqa: E501
        if offset is not None and offset < 0:  # noqa: E501
            raise ValueError(
                "Invalid value for `offset`, must be a value greater than or equal to `0`"
            )  # noqa: E501

        self._offset = offset

    @property
    def sort_order(self):
        """Gets the sort_order of this SubscriptionFilterParameters.  # noqa: E501

        Sort based on order of results. 'asc' for ascending order or 'desc' for descending order (default value)  # noqa: E501

        :return: The sort_order of this SubscriptionFilterParameters.  # noqa: E501
        :rtype: str
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this SubscriptionFilterParameters.

        Sort based on order of results. 'asc' for ascending order or 'desc' for descending order (default value)  # noqa: E501

        :param sort_order: The sort_order of this SubscriptionFilterParameters.  # noqa: E501
        :type: str
        """
        if sort_order is not None and not re.search(
            r"asc|desc", sort_order
        ):  # noqa: E501
            raise ValueError(
                r"Invalid value for `sort_order`, must be a follow pattern or equal to `/asc|desc/`"
            )  # noqa: E501

        self._sort_order = sort_order

    @property
    def customer_id(self):
        """Gets the customer_id of this SubscriptionFilterParameters.  # noqa: E501

        Merchant identifier of customer account  # noqa: E501

        :return: The customer_id of this SubscriptionFilterParameters.  # noqa: E501
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this SubscriptionFilterParameters.

        Merchant identifier of customer account  # noqa: E501

        :param customer_id: The customer_id of this SubscriptionFilterParameters.  # noqa: E501
        :type: str
        """
        if customer_id is not None and len(customer_id) > 32:
            raise ValueError(
                "Invalid value for `customer_id`, length must be less than or equal to `32`"
            )  # noqa: E501
        if customer_id is not None and len(customer_id) < 0:
            raise ValueError(
                "Invalid value for `customer_id`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._customer_id = customer_id

    @property
    def plan_id(self):
        """Gets the plan_id of this SubscriptionFilterParameters.  # noqa: E501

        Id of plan. Use for searching scheduled subscriptions by plan  # noqa: E501

        :return: The plan_id of this SubscriptionFilterParameters.  # noqa: E501
        :rtype: str
        """
        return self._plan_id

    @plan_id.setter
    def plan_id(self, plan_id):
        """Sets the plan_id of this SubscriptionFilterParameters.

        Id of plan. Use for searching scheduled subscriptions by plan  # noqa: E501

        :param plan_id: The plan_id of this SubscriptionFilterParameters.  # noqa: E501
        :type: str
        """
        if plan_id is not None and len(plan_id) > 32:
            raise ValueError(
                "Invalid value for `plan_id`, length must be less than or equal to `32`"
            )  # noqa: E501
        if plan_id is not None and len(plan_id) < 0:
            raise ValueError(
                "Invalid value for `plan_id`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._plan_id = plan_id

    @property
    def start_time(self):
        """Gets the start_time of this SubscriptionFilterParameters.  # noqa: E501

        Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period starts (inclusive), UTC time, default is 24 hours before 'end_time' (format: yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :return: The start_time of this SubscriptionFilterParameters.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this SubscriptionFilterParameters.

        Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period starts (inclusive), UTC time, default is 24 hours before 'end_time' (format: yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :param start_time: The start_time of this SubscriptionFilterParameters.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this SubscriptionFilterParameters.  # noqa: E501

        Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period ends (not inclusive), UTC time, must be less than 7 days after 'start_time', default is current time (format: yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :return: The end_time of this SubscriptionFilterParameters.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this SubscriptionFilterParameters.

        Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period ends (not inclusive), UTC time, must be less than 7 days after 'start_time', default is current time (format: yyyy-MM-dd'T'HH:mm:ss'Z')  # noqa: E501

        :param end_time: The end_time of this SubscriptionFilterParameters.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def currency(self):
        """Gets the currency of this SubscriptionFilterParameters.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of transactions currency  # noqa: E501

        :return: The currency of this SubscriptionFilterParameters.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this SubscriptionFilterParameters.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of transactions currency  # noqa: E501

        :param currency: The currency of this SubscriptionFilterParameters.  # noqa: E501
        :type: str
        """

        self._currency = currency

    class Status(object):
        ACTIVE = "ACTIVE"
        INACTIVE = "INACTIVE"
        CANCELLED = "CANCELLED"
        PAST_DUE = "PAST_DUE"
        PENDING = "PENDING"
        COMPLETED = "COMPLETED"
        CARD_EXPIRED = "CARD_EXPIRED"
        ACTIVATION_FAILED = "ACTIVATION_FAILED"

    @property
    def status(self):
        """Gets the status of this SubscriptionFilterParameters.  # noqa: E501

        Status of subscription  # noqa: E501

        :return: The status of this SubscriptionFilterParameters.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SubscriptionFilterParameters.

        Status of subscription  # noqa: E501

        :param status: The status of this SubscriptionFilterParameters.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "ACTIVE",
            "INACTIVE",
            "CANCELLED",
            "PAST_DUE",
            "PENDING",
            "COMPLETED",
            "CARD_EXPIRED",
            "ACTIVATION_FAILED",
        ]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    class Type(object):
        ONECLICK = "ONECLICK"
        SCHEDULED = "SCHEDULED"
        INSTALLMENT = "INSTALLMENT"

    @property
    def type(self):
        """Gets the type of this SubscriptionFilterParameters.  # noqa: E501

        Type of subscription. 'ONECLICK' type will be ignored.  # noqa: E501

        :return: The type of this SubscriptionFilterParameters.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SubscriptionFilterParameters.

        Type of subscription. 'ONECLICK' type will be ignored.  # noqa: E501

        :param type: The type of this SubscriptionFilterParameters.  # noqa: E501
        :type: str
        """
        allowed_values = ["ONECLICK", "SCHEDULED", "INSTALLMENT"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                    type, allowed_values
                )
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(SubscriptionFilterParameters, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubscriptionFilterParameters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.payment_request_card_account import (
    PaymentRequestCardAccount,
)  # noqa: F401,E501
from cardpay.model.payment_request_customer import (
    PaymentRequestCustomer,
)  # noqa: F401,E501
from cardpay.model.payment_request_merchant_order import (
    PaymentRequestMerchantOrder,
)  # noqa: F401,E501
from cardpay.model.payment_request_payment_data import (
    PaymentRequestPaymentData,
)  # noqa: F401,E501
from cardpay.model.request import Request  # noqa: F401,E501
from cardpay.model.return_urls import ReturnUrls  # noqa: F401,E501


class AuthenticationRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "request": "Request",
        "card_account": "PaymentRequestCardAccount",
        "customer": "PaymentRequestCustomer",
        "merchant_order": "PaymentRequestMerchantOrder",
        "payment_data": "PaymentRequestPaymentData",
        "payment_method": "str",
        "return_urls": "ReturnUrls",
    }

    attribute_map = {
        "request": "request",
        "card_account": "card_account",
        "customer": "customer",
        "merchant_order": "merchant_order",
        "payment_data": "payment_data",
        "payment_method": "payment_method",
        "return_urls": "return_urls",
    }

    def __init__(
        self,
        request=None,
        card_account=None,
        customer=None,
        merchant_order=None,
        payment_data=None,
        payment_method=None,
        return_urls=None,
    ):  # noqa: E501
        """AuthenticationRequest - a model defined in Swagger"""  # noqa: E501

        self._request = None
        self._card_account = None
        self._customer = None
        self._merchant_order = None
        self._payment_data = None
        self._payment_method = None
        self._return_urls = None
        self.discriminator = None

        self.request = request
        self.card_account = card_account
        self.customer = customer
        self.merchant_order = merchant_order
        self.payment_data = payment_data
        if payment_method is not None:
            self.payment_method = payment_method
        if return_urls is not None:
            self.return_urls = return_urls

    @property
    def request(self):
        """Gets the request of this AuthenticationRequest.  # noqa: E501

        Request  # noqa: E501

        :return: The request of this AuthenticationRequest.  # noqa: E501
        :rtype: Request
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this AuthenticationRequest.

        Request  # noqa: E501

        :param request: The request of this AuthenticationRequest.  # noqa: E501
        :type: Request
        """
        if request is None:
            raise ValueError(
                "Invalid value for `request`, must not be `None`"
            )  # noqa: E501

        self._request = request

    @property
    def card_account(self):
        """Gets the card_account of this AuthenticationRequest.  # noqa: E501

        Information about card *(for BANKCARD payment method only)*  # noqa: E501

        :return: The card_account of this AuthenticationRequest.  # noqa: E501
        :rtype: PaymentRequestCardAccount
        """
        return self._card_account

    @card_account.setter
    def card_account(self, card_account):
        """Sets the card_account of this AuthenticationRequest.

        Information about card *(for BANKCARD payment method only)*  # noqa: E501

        :param card_account: The card_account of this AuthenticationRequest.  # noqa: E501
        :type: PaymentRequestCardAccount
        """
        if card_account is None:
            raise ValueError(
                "Invalid value for `card_account`, must not be `None`"
            )  # noqa: E501

        self._card_account = card_account

    @property
    def customer(self):
        """Gets the customer of this AuthenticationRequest.  # noqa: E501

        Customer data  # noqa: E501

        :return: The customer of this AuthenticationRequest.  # noqa: E501
        :rtype: PaymentRequestCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this AuthenticationRequest.

        Customer data  # noqa: E501

        :param customer: The customer of this AuthenticationRequest.  # noqa: E501
        :type: PaymentRequestCustomer
        """
        if customer is None:
            raise ValueError(
                "Invalid value for `customer`, must not be `None`"
            )  # noqa: E501

        self._customer = customer

    @property
    def merchant_order(self):
        """Gets the merchant_order of this AuthenticationRequest.  # noqa: E501

        Merchant order data  # noqa: E501

        :return: The merchant_order of this AuthenticationRequest.  # noqa: E501
        :rtype: PaymentRequestMerchantOrder
        """
        return self._merchant_order

    @merchant_order.setter
    def merchant_order(self, merchant_order):
        """Sets the merchant_order of this AuthenticationRequest.

        Merchant order data  # noqa: E501

        :param merchant_order: The merchant_order of this AuthenticationRequest.  # noqa: E501
        :type: PaymentRequestMerchantOrder
        """
        if merchant_order is None:
            raise ValueError(
                "Invalid value for `merchant_order`, must not be `None`"
            )  # noqa: E501

        self._merchant_order = merchant_order

    @property
    def payment_data(self):
        """Gets the payment_data of this AuthenticationRequest.  # noqa: E501

        Payment data  # noqa: E501

        :return: The payment_data of this AuthenticationRequest.  # noqa: E501
        :rtype: PaymentRequestPaymentData
        """
        return self._payment_data

    @payment_data.setter
    def payment_data(self, payment_data):
        """Sets the payment_data of this AuthenticationRequest.

        Payment data  # noqa: E501

        :param payment_data: The payment_data of this AuthenticationRequest.  # noqa: E501
        :type: PaymentRequestPaymentData
        """
        if payment_data is None:
            raise ValueError(
                "Invalid value for `payment_data`, must not be `None`"
            )  # noqa: E501

        self._payment_data = payment_data

    @property
    def payment_method(self):
        """Gets the payment_method of this AuthenticationRequest.  # noqa: E501

        Used payment method type name from payment methods list  # noqa: E501

        :return: The payment_method of this AuthenticationRequest.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this AuthenticationRequest.

        Used payment method type name from payment methods list  # noqa: E501

        :param payment_method: The payment_method of this AuthenticationRequest.  # noqa: E501
        :type: str
        """

        self._payment_method = payment_method

    @property
    def return_urls(self):
        """Gets the return_urls of this AuthenticationRequest.  # noqa: E501

        Return URLs are the URLs where Customer returns by pressing 'Back to the shop' or 'Cancel' button in Payment page mode and redirected automatically in Gateway mode  # noqa: E501

        :return: The return_urls of this AuthenticationRequest.  # noqa: E501
        :rtype: ReturnUrls
        """
        return self._return_urls

    @return_urls.setter
    def return_urls(self, return_urls):
        """Sets the return_urls of this AuthenticationRequest.

        Return URLs are the URLs where Customer returns by pressing 'Back to the shop' or 'Cancel' button in Payment page mode and redirected automatically in Gateway mode  # noqa: E501

        :param return_urls: The return_urls of this AuthenticationRequest.  # noqa: E501
        :type: ReturnUrls
        """

        self._return_urls = return_urls

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(AuthenticationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuthenticationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.payment_request_living_address import (
    PaymentRequestLivingAddress,
)  # noqa: F401,E501


class PaymentRequestCustomer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "birth_date": "datetime",
        "email": "str",
        "full_name": "str",
        "home_phone": "str",
        "id": "str",
        "living_address": "PaymentRequestLivingAddress",
        "locale": "str",
        "phone": "str",
        "work_phone": "str",
        "ip": "str",
    }

    attribute_map = {
        "birth_date": "birth_date",
        "email": "email",
        "full_name": "full_name",
        "home_phone": "home_phone",
        "id": "id",
        "living_address": "living_address",
        "locale": "locale",
        "phone": "phone",
        "work_phone": "work_phone",
        "ip": "ip",
    }

    def __init__(
        self,
        birth_date=None,
        email=None,
        full_name=None,
        home_phone=None,
        id=None,
        living_address=None,
        locale=None,
        phone=None,
        work_phone=None,
        ip=None,
    ):  # noqa: E501
        """PaymentRequestCustomer - a model defined in Swagger"""  # noqa: E501

        self._birth_date = None
        self._email = None
        self._full_name = None
        self._home_phone = None
        self._id = None
        self._living_address = None
        self._locale = None
        self._phone = None
        self._work_phone = None
        self._ip = None
        self.discriminator = None

        if birth_date is not None:
            self.birth_date = birth_date
        if email is not None:
            self.email = email
        if full_name is not None:
            self.full_name = full_name
        if home_phone is not None:
            self.home_phone = home_phone
        if id is not None:
            self.id = id
        if living_address is not None:
            self.living_address = living_address
        if locale is not None:
            self.locale = locale
        if phone is not None:
            self.phone = phone
        if work_phone is not None:
            self.work_phone = work_phone
        if ip is not None:
            self.ip = ip

    @property
    def birth_date(self):
        """Gets the birth_date of this PaymentRequestCustomer.  # noqa: E501

        Customer birth date in format `YYYY-MM-DD`. For Zenith bank in DIRECTBANKINGNGA: Customer password in format date of birth. *(mandatory for DIRECTBANKINGNGA payment method only)*  # noqa: E501

        :return: The birth_date of this PaymentRequestCustomer.  # noqa: E501
        :rtype: datetime
        """
        return self._birth_date

    @birth_date.setter
    def birth_date(self, birth_date):
        """Sets the birth_date of this PaymentRequestCustomer.

        Customer birth date in format `YYYY-MM-DD`. For Zenith bank in DIRECTBANKINGNGA: Customer password in format date of birth. *(mandatory for DIRECTBANKINGNGA payment method only)*  # noqa: E501

        :param birth_date: The birth_date of this PaymentRequestCustomer.  # noqa: E501
        :type: datetime
        """

        self._birth_date = birth_date

    @property
    def email(self):
        """Gets the email of this PaymentRequestCustomer.  # noqa: E501

        Email address of Customer *(mandatory by default for BANKCARD, PAYPAL, 'Latin America', AIRTEL, MPESA, MTN, UGANDAMOBILE, VODAFONE, TIGO, DIRECTBANKINGNGA and AQRCODE payment methods only)*. Can be defined as optional by CardPay manager.  # noqa: E501

        :return: The email of this PaymentRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this PaymentRequestCustomer.

        Email address of Customer *(mandatory by default for BANKCARD, PAYPAL, 'Latin America', AIRTEL, MPESA, MTN, UGANDAMOBILE, VODAFONE, TIGO, DIRECTBANKINGNGA and AQRCODE payment methods only)*. Can be defined as optional by CardPay manager.  # noqa: E501

        :param email: The email of this PaymentRequestCustomer.  # noqa: E501
        :type: str
        """
        if email is not None and len(email) > 256:
            raise ValueError(
                "Invalid value for `email`, length must be less than or equal to `256`"
            )  # noqa: E501
        if email is not None and len(email) < 1:
            raise ValueError(
                "Invalid value for `email`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._email = email

    @property
    def full_name(self):
        """Gets the full_name of this PaymentRequestCustomer.  # noqa: E501

        Customer full name *(mandatory for 'Latin America' payment methods only)*  # noqa: E501

        :return: The full_name of this PaymentRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this PaymentRequestCustomer.

        Customer full name *(mandatory for 'Latin America' payment methods only)*  # noqa: E501

        :param full_name: The full_name of this PaymentRequestCustomer.  # noqa: E501
        :type: str
        """
        if full_name is not None and len(full_name) > 256:
            raise ValueError(
                "Invalid value for `full_name`, length must be less than or equal to `256`"
            )  # noqa: E501
        if full_name is not None and len(full_name) < 1:
            raise ValueError(
                "Invalid value for `full_name`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._full_name = full_name

    @property
    def home_phone(self):
        """Gets the home_phone of this PaymentRequestCustomer.  # noqa: E501

        The work phone number provided by the Cardholder. Required (if available), unless market or regional mandate restricts sending this information. Characters Format: string (10-18 symbols) country code + Subscriber number. Refer to ITU-E.164 for additional information on format and length.  # noqa: E501

        :return: The home_phone of this PaymentRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._home_phone

    @home_phone.setter
    def home_phone(self, home_phone):
        """Sets the home_phone of this PaymentRequestCustomer.

        The work phone number provided by the Cardholder. Required (if available), unless market or regional mandate restricts sending this information. Characters Format: string (10-18 symbols) country code + Subscriber number. Refer to ITU-E.164 for additional information on format and length.  # noqa: E501

        :param home_phone: The home_phone of this PaymentRequestCustomer.  # noqa: E501
        :type: str
        """
        if home_phone is not None and len(home_phone) > 18:
            raise ValueError(
                "Invalid value for `home_phone`, length must be less than or equal to `18`"
            )  # noqa: E501
        if home_phone is not None and len(home_phone) < 8:
            raise ValueError(
                "Invalid value for `home_phone`, length must be greater than or equal to `8`"
            )  # noqa: E501

        self._home_phone = home_phone

    @property
    def id(self):
        """Gets the id of this PaymentRequestCustomer.  # noqa: E501

        Customer ID in Merchant's system *(mandatory for WEBMONEY payment method only)*  # noqa: E501

        :return: The id of this PaymentRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentRequestCustomer.

        Customer ID in Merchant's system *(mandatory for WEBMONEY payment method only)*  # noqa: E501

        :param id: The id of this PaymentRequestCustomer.  # noqa: E501
        :type: str
        """
        if id is not None and len(id) > 256:
            raise ValueError(
                "Invalid value for `id`, length must be less than or equal to `256`"
            )  # noqa: E501
        if id is not None and len(id) < 0:
            raise ValueError(
                "Invalid value for `id`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._id = id

    @property
    def living_address(self):
        """Gets the living_address of this PaymentRequestCustomer.  # noqa: E501

        Customer address *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = CO  # noqa: E501

        :return: The living_address of this PaymentRequestCustomer.  # noqa: E501
        :rtype: PaymentRequestLivingAddress
        """
        return self._living_address

    @living_address.setter
    def living_address(self, living_address):
        """Sets the living_address of this PaymentRequestCustomer.

        Customer address *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = CO  # noqa: E501

        :param living_address: The living_address of this PaymentRequestCustomer.  # noqa: E501
        :type: PaymentRequestLivingAddress
        """

        self._living_address = living_address

    @property
    def locale(self):
        """Gets the locale of this PaymentRequestCustomer.  # noqa: E501

        Preferred locale for the payment page ([ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) language code). The default locale will be applied if the selected locale is not supported. Supported locales are: `ru`, `en`, `zh`, `ja`  # noqa: E501

        :return: The locale of this PaymentRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this PaymentRequestCustomer.

        Preferred locale for the payment page ([ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) language code). The default locale will be applied if the selected locale is not supported. Supported locales are: `ru`, `en`, `zh`, `ja`  # noqa: E501

        :param locale: The locale of this PaymentRequestCustomer.  # noqa: E501
        :type: str
        """

        self._locale = locale

    @property
    def phone(self):
        """Gets the phone of this PaymentRequestCustomer.  # noqa: E501

        Customer phone number. Format: `+` sign and 10 or 11 digits, example: `+12345678901` Mandatory for DIRECTBANKINGNGA payment method. For other payment methods: optional by default, can be defined as mandatory by CardPay manager.  # noqa: E501

        :return: The phone of this PaymentRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this PaymentRequestCustomer.

        Customer phone number. Format: `+` sign and 10 or 11 digits, example: `+12345678901` Mandatory for DIRECTBANKINGNGA payment method. For other payment methods: optional by default, can be defined as mandatory by CardPay manager.  # noqa: E501

        :param phone: The phone of this PaymentRequestCustomer.  # noqa: E501
        :type: str
        """
        if phone is not None and len(phone) > 18:
            raise ValueError(
                "Invalid value for `phone`, length must be less than or equal to `18`"
            )  # noqa: E501
        if phone is not None and len(phone) < 8:
            raise ValueError(
                "Invalid value for `phone`, length must be greater than or equal to `8`"
            )  # noqa: E501

        self._phone = phone

    @property
    def work_phone(self):
        """Gets the work_phone of this PaymentRequestCustomer.  # noqa: E501

        The home phone number provided by the Cardholder. Required (if available) unless market or regional mandate restricts sending this information. Characters Format: string (10-18 symbols) country code + Subscriber number. Refer to ITU-E.164 for additional information on format and length.  # noqa: E501

        :return: The work_phone of this PaymentRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._work_phone

    @work_phone.setter
    def work_phone(self, work_phone):
        """Sets the work_phone of this PaymentRequestCustomer.

        The home phone number provided by the Cardholder. Required (if available) unless market or regional mandate restricts sending this information. Characters Format: string (10-18 symbols) country code + Subscriber number. Refer to ITU-E.164 for additional information on format and length.  # noqa: E501

        :param work_phone: The work_phone of this PaymentRequestCustomer.  # noqa: E501
        :type: str
        """
        if work_phone is not None and len(work_phone) > 18:
            raise ValueError(
                "Invalid value for `work_phone`, length must be less than or equal to `18`"
            )  # noqa: E501
        if work_phone is not None and len(work_phone) < 8:
            raise ValueError(
                "Invalid value for `work_phone`, length must be greater than or equal to `8`"
            )  # noqa: E501

        self._work_phone = work_phone

    @property
    def ip(self):
        """Gets the ip of this PaymentRequestCustomer.  # noqa: E501

        IP address of Customer  # noqa: E501

        :return: The ip of this PaymentRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this PaymentRequestCustomer.

        IP address of Customer  # noqa: E501

        :param ip: The ip of this PaymentRequestCustomer.  # noqa: E501
        :type: str
        """

        self._ip = ip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentRequestCustomer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentRequestCustomer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import ApiClient
from cardpay.api_client import ApiClient
from cardpay.configuration import Configuration

# import models into sdk package
from cardpay.model.api_error import ApiError
from cardpay.model.api_tokens import ApiTokens
from cardpay.model.authentication_data import AuthenticationData
from cardpay.model.authentication_error import AuthenticationError
from cardpay.model.authentication_request import AuthenticationRequest
from cardpay.model.authentication_response import AuthenticationResponse
from cardpay.model.bad_request_error import BadRequestError
from cardpay.model.bank_card_payout_data import BankCardPayoutData
from cardpay.model.billing_address import BillingAddress
from cardpay.model.card_binding_card import CardBindingCard
from cardpay.model.card_binding_card_account import CardBindingCardAccount
from cardpay.model.card_binding_data import CardBindingData
from cardpay.model.card_binding_merchant_order import CardBindingMerchantOrder
from cardpay.model.card_binding_recurring_data_response import (
    CardBindingRecurringDataResponse,
)
from cardpay.model.card_binding_request import CardBindingRequest
from cardpay.model.card_binding_response import CardBindingResponse
from cardpay.model.change_subscription_status_claim_response import (
    ChangeSubscriptionStatusClaimResponse,
)
from cardpay.model.changed_plan_data import ChangedPlanData
from cardpay.model.claim_response_subscription_data import ClaimResponseSubscriptionData
from cardpay.model.confirm3ds_request import Confirm3dsRequest
from cardpay.model.filing_recurring_data import FilingRecurringData
from cardpay.model.filing_request import FilingRequest
from cardpay.model.filing_request_merchant_order import FilingRequestMerchantOrder
from cardpay.model.filing_request_subscription_data import FilingRequestSubscriptionData
from cardpay.model.filter_parameters import FilterParameters
from cardpay.model.flight import Flight
from cardpay.model.flights import Flights
from cardpay.model.installment_data import InstallmentData
from cardpay.model.installment_subscription_request import (
    InstallmentSubscriptionRequest,
)
from cardpay.model.item import Item
from cardpay.model.limit_info_response import LimitInfoResponse
from cardpay.model.mobile_payment_merchant_order import MobilePaymentMerchantOrder
from cardpay.model.mobile_payment_request import MobilePaymentRequest
from cardpay.model.mobile_payment_response import MobilePaymentResponse
from cardpay.model.mobile_token_request import MobileTokenRequest
from cardpay.model.mobile_token_response import MobileTokenResponse
from cardpay.model.next_subscription_payment import NextSubscriptionPayment
from cardpay.model.not_found_error import NotFoundError
from cardpay.model.o_auth_error import OAuthError
from cardpay.model.oneclick_data import OneclickData
from cardpay.model.payment_callback import PaymentCallback
from cardpay.model.payment_gateway_creation_response import (
    PaymentGatewayCreationResponse,
)
from cardpay.model.payment_gateway_response_payment_data import (
    PaymentGatewayResponsePaymentData,
)
from cardpay.model.payment_patch_request import PaymentPatchRequest
from cardpay.model.payment_request import PaymentRequest
from cardpay.model.payment_request_card import PaymentRequestCard
from cardpay.model.payment_request_card_account import PaymentRequestCardAccount
from cardpay.model.payment_request_cryptocurrency_account import (
    PaymentRequestCryptocurrencyAccount,
)
from cardpay.model.payment_request_customer import PaymentRequestCustomer
from cardpay.model.payment_request_e_wallet_account import PaymentRequestEWalletAccount
from cardpay.model.payment_request_living_address import PaymentRequestLivingAddress
from cardpay.model.payment_request_merchant_order import PaymentRequestMerchantOrder
from cardpay.model.payment_request_payment_data import PaymentRequestPaymentData
from cardpay.model.payment_response import PaymentResponse
from cardpay.model.payment_response_card_account import PaymentResponseCardAccount
from cardpay.model.payment_response_cryptocurrency_account import (
    PaymentResponseCryptocurrencyAccount,
)
from cardpay.model.payment_response_customer import PaymentResponseCustomer
from cardpay.model.payment_response_payment_data import PaymentResponsePaymentData
from cardpay.model.payment_update_response import PaymentUpdateResponse
from cardpay.model.payment_update_transaction_data import PaymentUpdateTransactionData
from cardpay.model.payments_list import PaymentsList
from cardpay.model.payout_callback import PayoutCallback
from cardpay.model.payout_creation_response import PayoutCreationResponse
from cardpay.model.payout_payment_data import PayoutPaymentData
from cardpay.model.payout_request import PayoutRequest
from cardpay.model.payout_request_card import PayoutRequestCard
from cardpay.model.payout_request_card_account import PayoutRequestCardAccount
from cardpay.model.payout_request_cryptocurrency_account import (
    PayoutRequestCryptocurrencyAccount,
)
from cardpay.model.payout_request_customer import PayoutRequestCustomer
from cardpay.model.payout_request_e_wallet_account import PayoutRequestEWalletAccount
from cardpay.model.payout_request_living_address import PayoutRequestLivingAddress
from cardpay.model.payout_request_merchant_order import PayoutRequestMerchantOrder
from cardpay.model.payout_request_payout_data import PayoutRequestPayoutData
from cardpay.model.payout_response import PayoutResponse
from cardpay.model.payout_response_card import PayoutResponseCard
from cardpay.model.payout_response_card_account import PayoutResponseCardAccount
from cardpay.model.payout_response_cryptocurrency_account import (
    PayoutResponseCryptocurrencyAccount,
)
from cardpay.model.payout_response_customer import PayoutResponseCustomer
from cardpay.model.payout_response_e_wallet_account import PayoutResponseEWalletAccount
from cardpay.model.payout_response_payout_data import PayoutResponsePayoutData
from cardpay.model.payout_update_request import PayoutUpdateRequest
from cardpay.model.payout_update_response import PayoutUpdateResponse
from cardpay.model.payouts_list import PayoutsList
from cardpay.model.plan import Plan
from cardpay.model.plan_data_list import PlanDataList
from cardpay.model.plan_update_request import PlanUpdateRequest
from cardpay.model.plan_update_request_plan_data import PlanUpdateRequestPlanData
from cardpay.model.plan_update_response import PlanUpdateResponse
from cardpay.model.recurring_callback import RecurringCallback
from cardpay.model.recurring_creation_request import RecurringCreationRequest
from cardpay.model.recurring_customer import RecurringCustomer
from cardpay.model.recurring_filter_parameters import RecurringFilterParameters
from cardpay.model.recurring_gateway_creation_response import (
    RecurringGatewayCreationResponse,
)
from cardpay.model.recurring_gateway_response_recurring_data import (
    RecurringGatewayResponseRecurringData,
)
from cardpay.model.recurring_patch_request import RecurringPatchRequest
from cardpay.model.recurring_plan_request import RecurringPlanRequest
from cardpay.model.recurring_plan_request_plan_data import RecurringPlanRequestPlanData
from cardpay.model.recurring_plan_response import RecurringPlanResponse
from cardpay.model.recurring_request_filing import RecurringRequestFiling
from cardpay.model.recurring_request_merchant_order import RecurringRequestMerchantOrder
from cardpay.model.recurring_request_recurring_data import RecurringRequestRecurringData
from cardpay.model.recurring_response import RecurringResponse
from cardpay.model.recurring_response_filing import RecurringResponseFiling
from cardpay.model.recurring_response_merchant_order import (
    RecurringResponseMerchantOrder,
)
from cardpay.model.recurring_response_recurring_data import (
    RecurringResponseRecurringData,
)
from cardpay.model.recurring_update_response import RecurringUpdateResponse
from cardpay.model.recurrings_list import RecurringsList
from cardpay.model.redirect_url_response import RedirectUrlResponse
from cardpay.model.refund_callback import RefundCallback
from cardpay.model.refund_request import RefundRequest
from cardpay.model.refund_request_customer import RefundRequestCustomer
from cardpay.model.refund_request_e_wallet_account import RefundRequestEWalletAccount
from cardpay.model.refund_request_merchant_order import RefundRequestMerchantOrder
from cardpay.model.refund_request_payment_data import RefundRequestPaymentData
from cardpay.model.refund_request_refund_data import RefundRequestRefundData
from cardpay.model.refund_response import RefundResponse
from cardpay.model.refund_response_card import RefundResponseCard
from cardpay.model.refund_response_card_account import RefundResponseCardAccount
from cardpay.model.refund_response_customer import RefundResponseCustomer
from cardpay.model.refund_response_e_wallet_account import RefundResponseEWalletAccount
from cardpay.model.refund_response_payment_data import RefundResponsePaymentData
from cardpay.model.refund_response_refund_data import RefundResponseRefundData
from cardpay.model.refund_update_request import RefundUpdateRequest
from cardpay.model.refund_update_response import RefundUpdateResponse
from cardpay.model.refunds_list import RefundsList
from cardpay.model.renamed_plan_data import RenamedPlanData
from cardpay.model.request import Request
from cardpay.model.request_updated_transaction_data import RequestUpdatedTransactionData
from cardpay.model.response_plan_data import ResponsePlanData
from cardpay.model.response_updated_transaction_data import (
    ResponseUpdatedTransactionData,
)
from cardpay.model.return_urls import ReturnUrls
from cardpay.model.schedule_option import ScheduleOption
from cardpay.model.schedule_options_response import ScheduleOptionsResponse
from cardpay.model.scheduled_data import ScheduledData
from cardpay.model.shipping_address import ShippingAddress
from cardpay.model.subscription import Subscription
from cardpay.model.subscription_customer import SubscriptionCustomer
from cardpay.model.subscription_filter_parameters import SubscriptionFilterParameters
from cardpay.model.subscription_get_response import SubscriptionGetResponse
from cardpay.model.subscription_get_response_plan import SubscriptionGetResponsePlan
from cardpay.model.subscription_list import SubscriptionList
from cardpay.model.subscription_update_request import SubscriptionUpdateRequest
from cardpay.model.subscription_update_request_subscription_data import (
    SubscriptionUpdateRequestSubscriptionData,
)
from cardpay.model.subscription_update_response import SubscriptionUpdateResponse
from cardpay.model.three_d_secure_data import ThreeDSecureData
from cardpay.model.transaction_request import TransactionRequest
from cardpay.model.transaction_response_e_wallet_account import (
    TransactionResponseEWalletAccount,
)
from cardpay.model.transaction_response_merchant_order import (
    TransactionResponseMerchantOrder,
)
from cardpay.model.transaction_update_request import TransactionUpdateRequest
from cardpay.model.updated_plan_data import UpdatedPlanData
from cardpay.model.updated_subscription_data import UpdatedSubscriptionData
from cardpay.model.updated_subscription_recurring_data import (
    UpdatedSubscriptionRecurringData,
)
from cardpay.model.payment_confirm3ds_request import PaymentConfirm3dsRequest
from cardpay.model.payment_update_request import PaymentUpdateRequest
from cardpay.model.recurring_confirm3ds_request import RecurringConfirm3dsRequest
from cardpay.model.recurring_update_request import RecurringUpdateRequest


# import apis into api package
from cardpay.api.auth_api import AuthApi
from cardpay.api.limits_api import LimitsApi
from cardpay.api.mobile_api import MobileApi
from cardpay.api.payments_api import PaymentsApi
from cardpay.api.payouts_api import PayoutsApi
from cardpay.api.recurrings_api import RecurringsApi
from cardpay.api.recurrings_installments_api import RecurringsInstallmentsApi
from cardpay.api.refunds_api import RefundsApi


def formatExpirationDate(date):
    return date.strftime("%m/%Y")


def formatBirthDate(date):
    return date.strftime("%Y-%m-%d")



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.schedule_option import ScheduleOption  # noqa: F401,E501


class ScheduleOptionsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "currency": "str",
        "options": "list[ScheduleOption]",
        "total_amount": "float",
    }

    attribute_map = {
        "currency": "currency",
        "options": "options",
        "total_amount": "total_amount",
    }

    def __init__(self, currency=None, options=None, total_amount=None):  # noqa: E501
        """ScheduleOptionsResponse - a model defined in Swagger"""  # noqa: E501

        self._currency = None
        self._options = None
        self._total_amount = None
        self.discriminator = None

        if currency is not None:
            self.currency = currency
        if options is not None:
            self.options = options
        if total_amount is not None:
            self.total_amount = total_amount

    @property
    def currency(self):
        """Gets the currency of this ScheduleOptionsResponse.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :return: The currency of this ScheduleOptionsResponse.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this ScheduleOptionsResponse.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :param currency: The currency of this ScheduleOptionsResponse.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def options(self):
        """Gets the options of this ScheduleOptionsResponse.  # noqa: E501

        Array of the calculated options data.  # noqa: E501

        :return: The options of this ScheduleOptionsResponse.  # noqa: E501
        :rtype: list[ScheduleOption]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this ScheduleOptionsResponse.

        Array of the calculated options data.  # noqa: E501

        :param options: The options of this ScheduleOptionsResponse.  # noqa: E501
        :type: list[ScheduleOption]
        """

        self._options = options

    @property
    def total_amount(self):
        """Gets the total_amount of this ScheduleOptionsResponse.  # noqa: E501

        Total amount of subscription to be calculated to options; can have dot as a decimal separator.  # noqa: E501

        :return: The total_amount of this ScheduleOptionsResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """Sets the total_amount of this ScheduleOptionsResponse.

        Total amount of subscription to be calculated to options; can have dot as a decimal separator.  # noqa: E501

        :param total_amount: The total_amount of this ScheduleOptionsResponse.  # noqa: E501
        :type: float
        """

        self._total_amount = total_amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ScheduleOptionsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScheduleOptionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ResponseUpdatedTransactionData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "details": "str",
        "id": "str",
        "is_executed": "bool",
        "status": "str",
        "status_to": "str",
        "updated": "datetime",
    }

    attribute_map = {
        "details": "details",
        "id": "id",
        "is_executed": "is_executed",
        "status": "status",
        "status_to": "status_to",
        "updated": "updated",
    }

    def __init__(
        self,
        details=None,
        id=None,
        is_executed=None,
        status=None,
        status_to=None,
        updated=None,
    ):  # noqa: E501
        """ResponseUpdatedTransactionData - a model defined in Swagger"""  # noqa: E501

        self._details = None
        self._id = None
        self._is_executed = None
        self._status = None
        self._status_to = None
        self._updated = None
        self.discriminator = None

        if details is not None:
            self.details = details
        if id is not None:
            self.id = id
        if is_executed is not None:
            self.is_executed = is_executed
        if status is not None:
            self.status = status
        if status_to is not None:
            self.status_to = status_to
        if updated is not None:
            self.updated = updated

    @property
    def details(self):
        """Gets the details of this ResponseUpdatedTransactionData.  # noqa: E501

        The reason why request was unsuccessful  # noqa: E501

        :return: The details of this ResponseUpdatedTransactionData.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this ResponseUpdatedTransactionData.

        The reason why request was unsuccessful  # noqa: E501

        :param details: The details of this ResponseUpdatedTransactionData.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def id(self):
        """Gets the id of this ResponseUpdatedTransactionData.  # noqa: E501

        Represents the ID of the modified transaction  # noqa: E501

        :return: The id of this ResponseUpdatedTransactionData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponseUpdatedTransactionData.

        Represents the ID of the modified transaction  # noqa: E501

        :param id: The id of this ResponseUpdatedTransactionData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_executed(self):
        """Gets the is_executed of this ResponseUpdatedTransactionData.  # noqa: E501

        Indicates was the request successful or not  # noqa: E501

        :return: The is_executed of this ResponseUpdatedTransactionData.  # noqa: E501
        :rtype: bool
        """
        return self._is_executed

    @is_executed.setter
    def is_executed(self, is_executed):
        """Sets the is_executed of this ResponseUpdatedTransactionData.

        Indicates was the request successful or not  # noqa: E501

        :param is_executed: The is_executed of this ResponseUpdatedTransactionData.  # noqa: E501
        :type: bool
        """

        self._is_executed = is_executed

    class Status(object):
        NEW = "NEW"
        IN_PROGRESS = "IN_PROGRESS"
        DECLINED = "DECLINED"
        AUTHORIZED = "AUTHORIZED"
        COMPLETED = "COMPLETED"
        CANCELLED = "CANCELLED"
        REFUNDED = "REFUNDED"
        PARTIALLY_REFUNDED = "PARTIALLY_REFUNDED"
        VOIDED = "VOIDED"
        CHARGED_BACK = "CHARGED_BACK"
        CHARGEBACK_RESOLVED = "CHARGEBACK_RESOLVED"

    @property
    def status(self):
        """Gets the status of this ResponseUpdatedTransactionData.  # noqa: E501

        Status of modified or created transaction  # noqa: E501

        :return: The status of this ResponseUpdatedTransactionData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ResponseUpdatedTransactionData.

        Status of modified or created transaction  # noqa: E501

        :param status: The status of this ResponseUpdatedTransactionData.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "NEW",
            "IN_PROGRESS",
            "DECLINED",
            "AUTHORIZED",
            "COMPLETED",
            "CANCELLED",
            "REFUNDED",
            "PARTIALLY_REFUNDED",
            "VOIDED",
            "CHARGED_BACK",
            "CHARGEBACK_RESOLVED",
        ]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    class StatusTo(object):
        REVERSE = "REVERSE"
        COMPLETE = "COMPLETE"

    @property
    def status_to(self):
        """Gets the status_to of this ResponseUpdatedTransactionData.  # noqa: E501

        Requested action (status to be set).  Payment: `COMPLETE` or `REVERSE`.  Refund, payout: `REVERSE`.  # noqa: E501

        :return: The status_to of this ResponseUpdatedTransactionData.  # noqa: E501
        :rtype: str
        """
        return self._status_to

    @status_to.setter
    def status_to(self, status_to):
        """Sets the status_to of this ResponseUpdatedTransactionData.

        Requested action (status to be set).  Payment: `COMPLETE` or `REVERSE`.  Refund, payout: `REVERSE`.  # noqa: E501

        :param status_to: The status_to of this ResponseUpdatedTransactionData.  # noqa: E501
        :type: str
        """
        allowed_values = ["REVERSE", "COMPLETE"]  # noqa: E501
        if status_to not in allowed_values:
            raise ValueError(
                "Invalid value for `status_to` ({0}), must be one of {1}".format(  # noqa: E501
                    status_to, allowed_values
                )
            )

        self._status_to = status_to

    @property
    def updated(self):
        """Gets the updated of this ResponseUpdatedTransactionData.  # noqa: E501

        Transaction update date and time in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format. Returned only for successful update operations.  # noqa: E501

        :return: The updated of this ResponseUpdatedTransactionData.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this ResponseUpdatedTransactionData.

        Transaction update date and time in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format. Returned only for successful update operations.  # noqa: E501

        :param updated: The updated of this ResponseUpdatedTransactionData.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ResponseUpdatedTransactionData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseUpdatedTransactionData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class InstallmentData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "float",
        "currency": "str",
        "dynamic_descriptor": "str",
        "generate_token": "bool",
        "hold_rest_amount": "bool",
        "initiator": "str",
        "interval": "int",
        "note": "str",
        "payments": "int",
        "period": "str",
        "retries": "int",
        "subscription_start": "datetime",
        "trans_type": "str",
    }

    attribute_map = {
        "amount": "amount",
        "currency": "currency",
        "dynamic_descriptor": "dynamic_descriptor",
        "generate_token": "generate_token",
        "hold_rest_amount": "hold_rest_amount",
        "initiator": "initiator",
        "interval": "interval",
        "note": "note",
        "payments": "payments",
        "period": "period",
        "retries": "retries",
        "subscription_start": "subscription_start",
        "trans_type": "trans_type",
    }

    def __init__(
        self,
        amount=None,
        currency=None,
        dynamic_descriptor=None,
        generate_token=None,
        hold_rest_amount=None,
        initiator=None,
        interval=None,
        note=None,
        payments=None,
        period=None,
        retries=None,
        subscription_start=None,
        trans_type=None,
    ):  # noqa: E501
        """InstallmentData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._currency = None
        self._dynamic_descriptor = None
        self._generate_token = None
        self._hold_rest_amount = None
        self._initiator = None
        self._interval = None
        self._note = None
        self._payments = None
        self._period = None
        self._retries = None
        self._subscription_start = None
        self._trans_type = None
        self.discriminator = None

        if amount is not None:
            self.amount = amount
        self.currency = currency
        if dynamic_descriptor is not None:
            self.dynamic_descriptor = dynamic_descriptor
        if generate_token is not None:
            self.generate_token = generate_token
        if hold_rest_amount is not None:
            self.hold_rest_amount = hold_rest_amount
        self.initiator = initiator
        if interval is not None:
            self.interval = interval
        if note is not None:
            self.note = note
        if payments is not None:
            self.payments = payments
        if period is not None:
            self.period = period
        if retries is not None:
            self.retries = retries
        if subscription_start is not None:
            self.subscription_start = subscription_start
        if trans_type is not None:
            self.trans_type = trans_type

    @property
    def amount(self):
        """Gets the amount of this InstallmentData.  # noqa: E501

        The total transaction amount in selected currency with dot as a decimal separator, must be less than 100 millions  # noqa: E501

        :return: The amount of this InstallmentData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this InstallmentData.

        The total transaction amount in selected currency with dot as a decimal separator, must be less than 100 millions  # noqa: E501

        :param amount: The amount of this InstallmentData.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this InstallmentData.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :return: The currency of this InstallmentData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InstallmentData.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :param currency: The currency of this InstallmentData.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError(
                "Invalid value for `currency`, must not be `None`"
            )  # noqa: E501

        self._currency = currency

    @property
    def dynamic_descriptor(self):
        """Gets the dynamic_descriptor of this InstallmentData.  # noqa: E501

        Short description of the service or product, must be enabled by CardPay manager to be used.  # noqa: E501

        :return: The dynamic_descriptor of this InstallmentData.  # noqa: E501
        :rtype: str
        """
        return self._dynamic_descriptor

    @dynamic_descriptor.setter
    def dynamic_descriptor(self, dynamic_descriptor):
        """Sets the dynamic_descriptor of this InstallmentData.

        Short description of the service or product, must be enabled by CardPay manager to be used.  # noqa: E501

        :param dynamic_descriptor: The dynamic_descriptor of this InstallmentData.  # noqa: E501
        :type: str
        """
        if dynamic_descriptor is not None and len(dynamic_descriptor) > 25:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be less than or equal to `25`"
            )  # noqa: E501
        if dynamic_descriptor is not None and len(dynamic_descriptor) < 0:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._dynamic_descriptor = dynamic_descriptor

    @property
    def generate_token(self):
        """Gets the generate_token of this InstallmentData.  # noqa: E501

        This attribute can be received only in first recurring request. In all requests with recurring_id card.token can't be generated. If set to 'true', Card token will be generated and returned in GET response. Will be generated only for successful transactions (not for declined).  # noqa: E501

        :return: The generate_token of this InstallmentData.  # noqa: E501
        :rtype: bool
        """
        return self._generate_token

    @generate_token.setter
    def generate_token(self, generate_token):
        """Sets the generate_token of this InstallmentData.

        This attribute can be received only in first recurring request. In all requests with recurring_id card.token can't be generated. If set to 'true', Card token will be generated and returned in GET response. Will be generated only for successful transactions (not for declined).  # noqa: E501

        :param generate_token: The generate_token of this InstallmentData.  # noqa: E501
        :type: bool
        """

        self._generate_token = generate_token

    @property
    def hold_rest_amount(self):
        """Gets the hold_rest_amount of this InstallmentData.  # noqa: E501

        For SplitPay subscription - \"true\"  # noqa: E501

        :return: The hold_rest_amount of this InstallmentData.  # noqa: E501
        :rtype: bool
        """
        return self._hold_rest_amount

    @hold_rest_amount.setter
    def hold_rest_amount(self, hold_rest_amount):
        """Sets the hold_rest_amount of this InstallmentData.

        For SplitPay subscription - \"true\"  # noqa: E501

        :param hold_rest_amount: The hold_rest_amount of this InstallmentData.  # noqa: E501
        :type: bool
        """

        self._hold_rest_amount = hold_rest_amount

    @property
    def initiator(self):
        """Gets the initiator of this InstallmentData.  # noqa: E501

        Use `cit` for initiator attribute (cardholder initiated transaction).  # noqa: E501

        :return: The initiator of this InstallmentData.  # noqa: E501
        :rtype: str
        """
        return self._initiator

    @initiator.setter
    def initiator(self, initiator):
        """Sets the initiator of this InstallmentData.

        Use `cit` for initiator attribute (cardholder initiated transaction).  # noqa: E501

        :param initiator: The initiator of this InstallmentData.  # noqa: E501
        :type: str
        """
        if initiator is None:
            raise ValueError(
                "Invalid value for `initiator`, must not be `None`"
            )  # noqa: E501
        if initiator is not None and not re.search(r"mit|cit", initiator):  # noqa: E501
            raise ValueError(
                r"Invalid value for `initiator`, must be a follow pattern or equal to `/mit|cit/`"
            )  # noqa: E501

        self._initiator = initiator

    @property
    def interval(self):
        """Gets the interval of this InstallmentData.  # noqa: E501

        Frequency interval of period, can be 1-365 depending on selected period value. Minimum value of period + interval can be 7 days / 1 week. Maximum value of period + interval plan can be 365 days / 52 weeks / 12 months / 1 year. 1-60 minutes - for **sandbox environment** and testing purpose only.  # noqa: E501

        :return: The interval of this InstallmentData.  # noqa: E501
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this InstallmentData.

        Frequency interval of period, can be 1-365 depending on selected period value. Minimum value of period + interval can be 7 days / 1 week. Maximum value of period + interval plan can be 365 days / 52 weeks / 12 months / 1 year. 1-60 minutes - for **sandbox environment** and testing purpose only.  # noqa: E501

        :param interval: The interval of this InstallmentData.  # noqa: E501
        :type: int
        """
        if interval is not None and interval < 1:  # noqa: E501
            raise ValueError(
                "Invalid value for `interval`, must be a value greater than or equal to `1`"
            )  # noqa: E501

        self._interval = interval

    @property
    def note(self):
        """Gets the note of this InstallmentData.  # noqa: E501

        Note about the recurring that will not be displayed to customer.  # noqa: E501

        :return: The note of this InstallmentData.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this InstallmentData.

        Note about the recurring that will not be displayed to customer.  # noqa: E501

        :param note: The note of this InstallmentData.  # noqa: E501
        :type: str
        """
        if note is not None and len(note) > 100:
            raise ValueError(
                "Invalid value for `note`, length must be less than or equal to `100`"
            )  # noqa: E501
        if note is not None and len(note) < 0:
            raise ValueError(
                "Invalid value for `note`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._note = note

    @property
    def payments(self):
        """Gets the payments of this InstallmentData.  # noqa: E501

        Number of total payments to be charged per defined interval, can be 2-200.  # noqa: E501

        :return: The payments of this InstallmentData.  # noqa: E501
        :rtype: int
        """
        return self._payments

    @payments.setter
    def payments(self, payments):
        """Sets the payments of this InstallmentData.

        Number of total payments to be charged per defined interval, can be 2-200.  # noqa: E501

        :param payments: The payments of this InstallmentData.  # noqa: E501
        :type: int
        """

        self._payments = payments

    class Period(object):
        MINUTE = "minute"
        DAY = "day"
        WEEK = "week"
        MONTH = "month"
        YEAR = "year"

    @property
    def period(self):
        """Gets the period of this InstallmentData.  # noqa: E501

        Initial period of recurring, can be `day`, `week`, `month`, `year`  # noqa: E501

        :return: The period of this InstallmentData.  # noqa: E501
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this InstallmentData.

        Initial period of recurring, can be `day`, `week`, `month`, `year`  # noqa: E501

        :param period: The period of this InstallmentData.  # noqa: E501
        :type: str
        """
        allowed_values = ["minute", "day", "week", "month", "year"]  # noqa: E501
        if period not in allowed_values:
            raise ValueError(
                "Invalid value for `period` ({0}), must be one of {1}".format(  # noqa: E501
                    period, allowed_values
                )
            )

        self._period = period

    @property
    def retries(self):
        """Gets the retries of this InstallmentData.  # noqa: E501

        Number of daily basis retry attempts in case of payment has not been captured successfully, from 1 to 15 attempts can be specified.  # noqa: E501

        :return: The retries of this InstallmentData.  # noqa: E501
        :rtype: int
        """
        return self._retries

    @retries.setter
    def retries(self, retries):
        """Sets the retries of this InstallmentData.

        Number of daily basis retry attempts in case of payment has not been captured successfully, from 1 to 15 attempts can be specified.  # noqa: E501

        :param retries: The retries of this InstallmentData.  # noqa: E501
        :type: int
        """

        self._retries = retries

    @property
    def subscription_start(self):
        """Gets the subscription_start of this InstallmentData.  # noqa: E501

        The date in yyyy-MM-dd format when subscription will actually become activated (grace period). Auth request will be created but Customer will be charged only when subscription start date comes. Leave it empty or specify the current date to activate subscription at once without any grace period applied.  # noqa: E501

        :return: The subscription_start of this InstallmentData.  # noqa: E501
        :rtype: datetime
        """
        return self._subscription_start

    @subscription_start.setter
    def subscription_start(self, subscription_start):
        """Sets the subscription_start of this InstallmentData.

        The date in yyyy-MM-dd format when subscription will actually become activated (grace period). Auth request will be created but Customer will be charged only when subscription start date comes. Leave it empty or specify the current date to activate subscription at once without any grace period applied.  # noqa: E501

        :param subscription_start: The subscription_start of this InstallmentData.  # noqa: E501
        :type: datetime
        """

        self._subscription_start = subscription_start

    class TransType(object):
        _01 = "01"
        _03 = "03"
        _10 = "10"
        _11 = "11"
        _28 = "28"

    @property
    def trans_type(self):
        """Gets the trans_type of this InstallmentData.  # noqa: E501


        :return: The trans_type of this InstallmentData.  # noqa: E501
        :rtype: str
        """
        return self._trans_type

    @trans_type.setter
    def trans_type(self, trans_type):
        """Sets the trans_type of this InstallmentData.


        :param trans_type: The trans_type of this InstallmentData.  # noqa: E501
        :type: str
        """
        allowed_values = ["01", "03", "10", "11", "28"]  # noqa: E501
        if trans_type not in allowed_values:
            raise ValueError(
                "Invalid value for `trans_type` ({0}), must be one of {1}".format(  # noqa: E501
                    trans_type, allowed_values
                )
            )

        self._trans_type = trans_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(InstallmentData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstallmentData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BillingAddress(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "addr_line_1": "str",
        "addr_line_2": "str",
        "city": "str",
        "country": "str",
        "phone": "str",
        "state": "str",
        "zip": "str",
    }

    attribute_map = {
        "addr_line_1": "addr_line_1",
        "addr_line_2": "addr_line_2",
        "city": "city",
        "country": "country",
        "phone": "phone",
        "state": "state",
        "zip": "zip",
    }

    def __init__(
        self,
        addr_line_1=None,
        addr_line_2=None,
        city=None,
        country=None,
        phone=None,
        state=None,
        zip=None,
    ):  # noqa: E501
        """BillingAddress - a model defined in Swagger"""  # noqa: E501

        self._addr_line_1 = None
        self._addr_line_2 = None
        self._city = None
        self._country = None
        self._phone = None
        self._state = None
        self._zip = None
        self.discriminator = None

        if addr_line_1 is not None:
            self.addr_line_1 = addr_line_1
        if addr_line_2 is not None:
            self.addr_line_2 = addr_line_2
        if city is not None:
            self.city = city
        if country is not None:
            self.country = country
        if phone is not None:
            self.phone = phone
        if state is not None:
            self.state = state
        if zip is not None:
            self.zip = zip

    @property
    def addr_line_1(self):
        """Gets the addr_line_1 of this BillingAddress.  # noqa: E501

        Street address. May include whitespaces, hyphens, apostrophes, commas, quotes, dots, slashes and semicolons  # noqa: E501

        :return: The addr_line_1 of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._addr_line_1

    @addr_line_1.setter
    def addr_line_1(self, addr_line_1):
        """Sets the addr_line_1 of this BillingAddress.

        Street address. May include whitespaces, hyphens, apostrophes, commas, quotes, dots, slashes and semicolons  # noqa: E501

        :param addr_line_1: The addr_line_1 of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._addr_line_1 = addr_line_1

    @property
    def addr_line_2(self):
        """Gets the addr_line_2 of this BillingAddress.  # noqa: E501

        Second line of the street address or equivalent local portion of the Cardholder billing address associated with the card used for this purchase.  # noqa: E501

        :return: The addr_line_2 of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._addr_line_2

    @addr_line_2.setter
    def addr_line_2(self, addr_line_2):
        """Sets the addr_line_2 of this BillingAddress.

        Second line of the street address or equivalent local portion of the Cardholder billing address associated with the card used for this purchase.  # noqa: E501

        :param addr_line_2: The addr_line_2 of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._addr_line_2 = addr_line_2

    @property
    def city(self):
        """Gets the city of this BillingAddress.  # noqa: E501

        Delivery city. May include whitespaces, hyphens, apostrophes, commas and dots  # noqa: E501

        :return: The city of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this BillingAddress.

        Delivery city. May include whitespaces, hyphens, apostrophes, commas and dots  # noqa: E501

        :param city: The city of this BillingAddress.  # noqa: E501
        :type: str
        """
        if city is not None and len(city) > 50:
            raise ValueError(
                "Invalid value for `city`, length must be less than or equal to `50`"
            )  # noqa: E501
        if city is not None and len(city) < 0:
            raise ValueError(
                "Invalid value for `city`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._city = city

    @property
    def country(self):
        """Gets the country of this BillingAddress.  # noqa: E501

        [ISO 3166-1](https://en.wikipedia.org/wiki/ISO_3166-1) code of country: 2 or 3 latin letters or numeric code. Mandatory if 'shipping_address' is presented.  # noqa: E501

        :return: The country of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this BillingAddress.

        [ISO 3166-1](https://en.wikipedia.org/wiki/ISO_3166-1) code of country: 2 or 3 latin letters or numeric code. Mandatory if 'shipping_address' is presented.  # noqa: E501

        :param country: The country of this BillingAddress.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def phone(self):
        """Gets the phone of this BillingAddress.  # noqa: E501

        Valid customer phone number  # noqa: E501

        :return: The phone of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this BillingAddress.

        Valid customer phone number  # noqa: E501

        :param phone: The phone of this BillingAddress.  # noqa: E501
        :type: str
        """
        if phone is not None and len(phone) > 20:
            raise ValueError(
                "Invalid value for `phone`, length must be less than or equal to `20`"
            )  # noqa: E501
        if phone is not None and len(phone) < 5:
            raise ValueError(
                "Invalid value for `phone`, length must be greater than or equal to `5`"
            )  # noqa: E501
        if phone is not None and not re.search(r"[-+\\d()wp\\s]+", phone):  # noqa: E501
            raise ValueError(
                r"Invalid value for `phone`, must be a follow pattern or equal to `/[-+\\d()wp\\s]+/`"
            )  # noqa: E501

        self._phone = phone

    @property
    def state(self):
        """Gets the state of this BillingAddress.  # noqa: E501

        Delivery state or province. May include whitespaces, hyphens, apostrophes, commas and dots  # noqa: E501

        :return: The state of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BillingAddress.

        Delivery state or province. May include whitespaces, hyphens, apostrophes, commas and dots  # noqa: E501

        :param state: The state of this BillingAddress.  # noqa: E501
        :type: str
        """
        if state is not None and len(state) > 40:
            raise ValueError(
                "Invalid value for `state`, length must be less than or equal to `40`"
            )  # noqa: E501
        if state is not None and len(state) < 0:
            raise ValueError(
                "Invalid value for `state`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._state = state

    @property
    def zip(self):
        """Gets the zip of this BillingAddress.  # noqa: E501

        Delivery postal code  # noqa: E501

        :return: The zip of this BillingAddress.  # noqa: E501
        :rtype: str
        """
        return self._zip

    @zip.setter
    def zip(self, zip):
        """Sets the zip of this BillingAddress.

        Delivery postal code  # noqa: E501

        :param zip: The zip of this BillingAddress.  # noqa: E501
        :type: str
        """
        if zip is not None and len(zip) > 12:
            raise ValueError(
                "Invalid value for `zip`, length must be less than or equal to `12`"
            )  # noqa: E501
        if zip is not None and len(zip) < 0:
            raise ValueError(
                "Invalid value for `zip`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._zip = zip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(BillingAddress, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BillingAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.flights import Flights  # noqa: F401,E501
from cardpay.model.item import Item  # noqa: F401,E501
from cardpay.model.shipping_address import ShippingAddress  # noqa: F401,E501


class PaymentRequestMerchantOrder(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "cryptocurrency_indicator": "bool",
        "description": "str",
        "flights": "Flights",
        "id": "str",
        "items": "list[Item]",
        "shipping_address": "ShippingAddress",
    }

    attribute_map = {
        "cryptocurrency_indicator": "cryptocurrency_indicator",
        "description": "description",
        "flights": "flights",
        "id": "id",
        "items": "items",
        "shipping_address": "shipping_address",
    }

    def __init__(
        self,
        cryptocurrency_indicator=None,
        description=None,
        flights=None,
        id=None,
        items=None,
        shipping_address=None,
    ):  # noqa: E501
        """PaymentRequestMerchantOrder - a model defined in Swagger"""  # noqa: E501

        self._cryptocurrency_indicator = None
        self._description = None
        self._flights = None
        self._id = None
        self._items = None
        self._shipping_address = None
        self.discriminator = None

        if cryptocurrency_indicator is not None:
            self.cryptocurrency_indicator = cryptocurrency_indicator
        self.description = description
        if flights is not None:
            self.flights = flights
        self.id = id
        if items is not None:
            self.items = items
        if shipping_address is not None:
            self.shipping_address = shipping_address

    @property
    def cryptocurrency_indicator(self):
        """Gets the cryptocurrency_indicator of this PaymentRequestMerchantOrder.  # noqa: E501

        Indicator should be added if there will be cryptocurrency purchase in transaction  # noqa: E501

        :return: The cryptocurrency_indicator of this PaymentRequestMerchantOrder.  # noqa: E501
        :rtype: bool
        """
        return self._cryptocurrency_indicator

    @cryptocurrency_indicator.setter
    def cryptocurrency_indicator(self, cryptocurrency_indicator):
        """Sets the cryptocurrency_indicator of this PaymentRequestMerchantOrder.

        Indicator should be added if there will be cryptocurrency purchase in transaction  # noqa: E501

        :param cryptocurrency_indicator: The cryptocurrency_indicator of this PaymentRequestMerchantOrder.  # noqa: E501
        :type: bool
        """

        self._cryptocurrency_indicator = cryptocurrency_indicator

    @property
    def description(self):
        """Gets the description of this PaymentRequestMerchantOrder.  # noqa: E501

        Description of product/service being sold  # noqa: E501

        :return: The description of this PaymentRequestMerchantOrder.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PaymentRequestMerchantOrder.

        Description of product/service being sold  # noqa: E501

        :param description: The description of this PaymentRequestMerchantOrder.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError(
                "Invalid value for `description`, must not be `None`"
            )  # noqa: E501
        if description is not None and len(description) > 200:
            raise ValueError(
                "Invalid value for `description`, length must be less than or equal to `200`"
            )  # noqa: E501
        if description is not None and len(description) < 1:
            raise ValueError(
                "Invalid value for `description`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._description = description

    @property
    def flights(self):
        """Gets the flights of this PaymentRequestMerchantOrder.  # noqa: E501

        Flights data *(for BANKCARD payment method only)*  # noqa: E501

        :return: The flights of this PaymentRequestMerchantOrder.  # noqa: E501
        :rtype: Flights
        """
        return self._flights

    @flights.setter
    def flights(self, flights):
        """Sets the flights of this PaymentRequestMerchantOrder.

        Flights data *(for BANKCARD payment method only)*  # noqa: E501

        :param flights: The flights of this PaymentRequestMerchantOrder.  # noqa: E501
        :type: Flights
        """

        self._flights = flights

    @property
    def id(self):
        """Gets the id of this PaymentRequestMerchantOrder.  # noqa: E501

        Order ID used by Merchant's shopping cart  # noqa: E501

        :return: The id of this PaymentRequestMerchantOrder.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentRequestMerchantOrder.

        Order ID used by Merchant's shopping cart  # noqa: E501

        :param id: The id of this PaymentRequestMerchantOrder.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if id is not None and len(id) > 50:
            raise ValueError(
                "Invalid value for `id`, length must be less than or equal to `50`"
            )  # noqa: E501
        if id is not None and len(id) < 1:
            raise ValueError(
                "Invalid value for `id`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._id = id

    @property
    def items(self):
        """Gets the items of this PaymentRequestMerchantOrder.  # noqa: E501

        Array of items (in the shopping cart)  # noqa: E501

        :return: The items of this PaymentRequestMerchantOrder.  # noqa: E501
        :rtype: list[Item]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this PaymentRequestMerchantOrder.

        Array of items (in the shopping cart)  # noqa: E501

        :param items: The items of this PaymentRequestMerchantOrder.  # noqa: E501
        :type: list[Item]
        """

        self._items = items

    @property
    def shipping_address(self):
        """Gets the shipping_address of this PaymentRequestMerchantOrder.  # noqa: E501

        Shipping Address  # noqa: E501

        :return: The shipping_address of this PaymentRequestMerchantOrder.  # noqa: E501
        :rtype: ShippingAddress
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """Sets the shipping_address of this PaymentRequestMerchantOrder.

        Shipping Address  # noqa: E501

        :param shipping_address: The shipping_address of this PaymentRequestMerchantOrder.  # noqa: E501
        :type: ShippingAddress
        """

        self._shipping_address = shipping_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentRequestMerchantOrder, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentRequestMerchantOrder):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
